# -*- coding: utf-8 -*-

# -*- coding: utf-8 -*-

# DO NOT EDIT THIS FILE!
# This file has been autogenerated by dephell <3
# https://github.com/dephell/dephell

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


import os.path

here = os.path.abspath(os.path.dirname(__file__))

setup(
    name='tenkan',
    version='0.2.2',
    long_description=open('README.md').read(),
    description='RSS/atom feed converter from html to gemini',
    long_description_content_type='text/markdown',
    python_requires='==3.*,>=3.8.0',
    project_urls={'repository': 'https://git.fqserv.eu/takaoni/tenkan'},
    author='Quentin Ferrand',
    author_email='quentin.ferrand@protonmail.com',
    license='WTFPL',
    entry_points={'console_scripts': ['tenkan = tenkan.cli:main']},
    packages=['tenkan'],
    package_dir={'': '.'},
    package_data={},
    install_requires=[
        'datetime==4.*,>=4.3.0',
        'feedgen==0.*,>=0.9.0',
        'feedparser==6.*,>=6.0.8',
        'markdownify==0.*,>=0.10.0',
        'md2gemini==1.*,>=1.8.1',
        'prettytable==3.*,>=3.0.0',
        'readability-lxml==0.*,>=0.8.1',
        'requests==2.*,>=2.26.0',
        'rich==10.*,>=10.16.2',
    ],
    extras_require={
        'dev': [
            'bandit==1.*,>=1.7.1',
            'black==21.*,>=21.11.0.b1',
            'flake8==4.*,>=4.0.1',
            'isort==5.*,>=5.10.1',
            'mypy==0.*,>=0.910.0',
            'pylint==2.*,>=2.12.2',
            'pytest==5.*,>=5.2.0',
            'pytest-cov==3.*,>=3.0.0',
            'pyupgrade==2.*,>=2.31.0',
        ]
    },
)
